__title__ = 'ka_uts_uts'
__description__ = 'IO Control & Package Management Utilities.'
__url__ = 'https://ka-uts-uts.readthedocs.io/en/latest'
__version__ = '4.0.3.250519'
__build__ = 0x022200
__author__ = 'Bernd Stroehle'
__author_email__ = 'bernd.stroehle@gmail.com'
__license__ = 'GPL-3.0-only WITH Classpath-Exception-2.0 OR BSD-3-Clause'
__copyright__ = 'Copyright 2025 Bernd Stroehle'
__cake__ = u'\u2728 \U0001f370 \u2728'
